import { Injectable } from '@angular/core';
import { Router } from '@angular/router';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { BehaviorSubject, Observable } from 'rxjs';

import { environment } from 'src/environments/environment';
import { AccountService } from 'src/app/services';
import { Needs } from 'src/app/models';


@Injectable({
  providedIn: 'root',
})
export class BasketService {
  httpOptions = {
    headers: new HttpHeaders({ 'Content-Type': 'application/json' })
  };

  constructor(
    private accountService: AccountService,
    private router: Router,
    private http: HttpClient
  ) { }

  getBasketNeeds() {
    let url = `/basket/${this.accountService.userValue?.id}`;
    console.log("GET " + url);
    return this.http.get<Needs[]>(url);
  }

  addNeedToBasket(id: number) {
    let url = `/basket/${this.accountService.userValue?.id}`;
    console.log("POST " + url + " " + id);
    return this.http.post<Needs>(url, id, this.httpOptions).subscribe();
  }

  removeNeedFromBasket(needID: number) {
    let url = `/basket/${this.accountService.userValue?.id}/${needID}`;
    console.log("DELETE " + url);
    this.http.delete<Needs>(url).subscribe();
  }

  getNeedFromBasket(needID: number) {
    let url = `/basket/${this.accountService.userValue?.id}/${needID}`;
    console.log("GET " + url);
    return this.http.get<Needs>(url);
  }

  checkout(needIDs: number[]) {
    let url = `/basket/${this.accountService.userValue?.id}/checkout`;
    console.log("POST " + url + " " + needIDs);
    this.http.post(url, needIDs, this.httpOptions).subscribe();
  }
}
